Module blaxel.core.client.models.job_execution_task
===================================================

Classes
-------

`JobExecutionTask(conditions: blaxel.core.client.types.Unset | list['JobExecutionTaskCondition'] = <blaxel.core.client.types.Unset object>, metadata: blaxel.core.client.types.Unset | ForwardRef('JobExecutionTaskMetadata') = <blaxel.core.client.types.Unset object>, spec: blaxel.core.client.types.Unset | ForwardRef('JobExecutionTaskSpec') = <blaxel.core.client.types.Unset object>, status: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>)`
:   Job execution task
    
    Attributes:
        conditions (Union[Unset, list['JobExecutionTaskCondition']]): Task conditions
        metadata (Union[Unset, JobExecutionTaskMetadata]): Job execution task metadata
        spec (Union[Unset, JobExecutionTaskSpec]): Job execution task specification
        status (Union[Unset, str]): Job execution task status
    
    Method generated by attrs for class JobExecutionTask.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties`
    :

    `conditions`
    :

    `metadata`
    :

    `spec`
    :

    `status`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :